@@ -14,6 +14,8 @@ import scipy.stats as st
 import random
 import string
 
+from mauspaf.core.misc import rodrigues_rotation
+
 
 class MassElement:
     """ Class to describe objects with mass properties.
@@ -93,6 +95,9 @@ class MassElement3D:
 
        I_{xy} = - \sum{m_{k} \cdot x_{k} \cdot y_{k}}
 
+    The moments and products of inertia are given around a coordinate system
+    parallel to the global coordinate system and located on the center of
+    gravity of the object.
 
     Attributes:
         mass (int or float or uncertain.UncertainValue): Mass of the element.
@@ -177,6 +182,58 @@ class MassElement3D:
     def __radd__(self, other):
         return self + other
 
+    def cg_vector(self):
+        """ Returns the cg as an array.
+
+        Returns:
+            numpy.ndarray: [1 x 3] Vector
+        """
+        return np.array([self.x, self.y, self.z])
+
+    def inertia_matrix(self):
+        """ Returns the inertial data as a matrix.
+
+        Returns:
+            numpy.ndarray: [3 x 3] Inertia matrix.
+        """
+        return np.array([[self.ixx, self.ixy, self.izx],
+                         [self.ixy, self.iyy, self.iyz],
+                         [self.izx, self.iyz, self.izz]])
+
+    def rotate(self, axis, angle, point=[0, 0, 0]):
+        """ Rotates the object around an axis by a given angle.
+
+        .. image:: ./../../resources/images/doc_inertia_rotation_01.svg
+
+        This function updates the center of gravity, moments and products of
+        inertia. If you want a new instance with the rotated properties, use a
+        copy (deepcopy) of the object.
+
+        Arguments:
+            axis (list or numpy.ndarray): Vector [1 x 3] describing the
+                rotation axis in the global coordinate system.
+            angle (float): Rotation angle.
+            point (list or numpy.ndarray or None): Vector [1 x 3] describing
+                the point the object is rotated around. The default value is
+                the center of gravity of the part.
+        """
+        rotation_matrix = rodrigues_rotation(axis, angle)
+
+        new_cg = rotation_matrix @ self.cg_vector()
+        self.x = new_cg[0]
+        self.y = new_cg[1]
+        self.z = new_cg[2]
+
+        new_inertia = np.transpose(rotation_matrix) @ self.inertia_matrix() \
+            @ rotation_matrix
+
+        self.ixx = new_inertia[0][0]
+        self.iyy = new_inertia[1][1]
+        self.izz = new_inertia[2][2]
+        self.ixy = new_inertia[0][1]
+        self.iyz = new_inertia[1][2]
+        self.izx = new_inertia[0][2]
+
     def describe(self):
         """ Prints the mass properties of the element.
         """
